@@ -329,8 +329,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
 
         except (SystemExit, KeyboardInterrupt):
             raise
-        except BaseException as e:
-            self._logger.exception(e)
+        except BaseException:
             return None
 
         arguments = library_node.get_tokens(RobotToken.ARGUMENT)
@@ -361,7 +360,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
         try:
             namespace = self.parent.documents_cache.get_namespace(document)
 
-            lib_doc = namespace.get_imported_variables_libdoc(library_node.name, library_node.args)
+            lib_doc = namespace.get_variables_import_libdoc(library_node.name, library_node.args)
 
             if lib_doc is None or lib_doc.errors:
                 lib_doc = namespace.imports_manager.get_libdoc_for_variables_import(
@@ -373,8 +372,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
 
         except (SystemExit, KeyboardInterrupt):
             raise
-        except BaseException as e:
-            self._logger.exception(e)
+        except BaseException:
             return None
 
         arguments = library_node.get_tokens(RobotToken.ARGUMENT)
