@@ -1,11 +1,8 @@
-from __future__ import annotations
-
 import ast
-import asyncio
+from concurrent.futures import CancelledError
 from typing import (
     TYPE_CHECKING,
     Any,
-    Awaitable,
     Callable,
     Optional,
     Sequence,
@@ -14,6 +11,10 @@ from typing import (
     cast,
 )
 
+from robot.parsing.lexer.tokens import Token
+from robot.parsing.model.statements import Statement
+
+from robotcode.core.language import language_id
 from robotcode.core.lsp.types import (
     MarkupContent,
     MarkupKind,
@@ -23,27 +24,35 @@ from robotcode.core.lsp.types import (
     SignatureHelpContext,
     SignatureInformation,
 )
+from robotcode.core.text_document import TextDocument
 from robotcode.core.utils.logging import LoggingDescriptor
+from robotcode.robot.diagnostics.library_doc import KeywordDoc, LibraryDoc
+from robotcode.robot.diagnostics.model_helper import ModelHelper
+from robotcode.robot.utils.ast import (
+    get_node_at_position,
+    get_tokens_at_position,
+    range_from_token,
+)
 
-from ...common.decorators import language_id, retrigger_characters, trigger_characters
-from ...common.text_document import TextDocument
-from ..diagnostics.library_doc import KeywordDoc, LibraryDoc
-from ..diagnostics.model_helper import ModelHelperMixin
-from ..utils.ast_utils import Statement, Token, get_node_at_position, get_tokens_at_position, range_from_token
+from ...common.decorators import (
+    retrigger_characters,
+    trigger_characters,
+)
 from .protocol_part import RobotLanguageServerProtocolPart
 
 if TYPE_CHECKING:
     from ..protocol import RobotLanguageServerProtocol
 
 _SignatureHelpMethod = Callable[
-    [ast.AST, TextDocument, Position, Optional[SignatureHelpContext]], Awaitable[Optional[SignatureHelp]]
+    [ast.AST, TextDocument, Position, Optional[SignatureHelpContext]],
+    Optional[SignatureHelp],
 ]
 
 
-class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
+class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
     _logger = LoggingDescriptor()
 
-    def __init__(self, parent: RobotLanguageServerProtocol) -> None:
+    def __init__(self, parent: "RobotLanguageServerProtocol") -> None:
         super().__init__(parent)
 
         parent.signature_help.collect.add(self.collect)
@@ -66,11 +75,17 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
     @trigger_characters([" ", "\t"])
     @retrigger_characters([" ", "\t"])
     @_logger.call
-    async def collect(
-        self, sender: Any, document: TextDocument, position: Position, context: Optional[SignatureHelpContext] = None
+    def collect(
+        self,
+        sender: Any,
+        document: TextDocument,
+        position: Position,
+        context: Optional[SignatureHelpContext] = None,
     ) -> Optional[SignatureHelp]:
-        result_node = await get_node_at_position(
-            await self.parent.documents_cache.get_model(document, False), position, include_end=True
+        result_node = get_node_at_position(
+            self.parent.documents_cache.get_model(document, False),
+            position,
+            include_end=True,
         )
         if result_node is None:
             return None
@@ -79,9 +94,9 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         if method is None:
             return None
 
-        return await method(result_node, document, position, context)
+        return method(result_node, document, position, context)
 
-    async def _signature_help_KeywordCall_or_Fixture(  # noqa: N802
+    def _signature_help_KeywordCall_or_Fixture(  # noqa: N802
         self,
         keyword_name_token_type: str,
         node: ast.AST,
@@ -100,7 +115,11 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
         token_at_position = tokens_at_position[-1]
 
-        if token_at_position.type not in [RobotToken.ARGUMENT, RobotToken.EOL, RobotToken.SEPARATOR]:
+        if token_at_position.type not in [
+            RobotToken.ARGUMENT,
+            RobotToken.EOL,
+            RobotToken.SEPARATOR,
+        ]:
             return None
 
         keyword_doc_and_token: Optional[Tuple[Optional[KeywordDoc], Token]] = None
@@ -109,9 +128,9 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         if keyword_token is None:
             return None
 
-        namespace = await self.parent.documents_cache.get_namespace(document)
+        namespace = self.parent.documents_cache.get_namespace(document)
 
-        keyword_doc_and_token = await self.get_keyworddoc_and_token_from_position(
+        keyword_doc_and_token = self.get_keyworddoc_and_token_from_position(
             keyword_token.value,
             keyword_token,
             [t for t in kw_node.get_tokens(RobotToken.ARGUMENT)],
@@ -154,12 +173,14 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
             parameters=[
                 ParameterInformation(
                     label=p.signature(),
-                    documentation=MarkupContent(
-                        kind=MarkupKind.MARKDOWN,
-                        value="\n\n---\n\n".join([t.to_markdown() for t in keyword_doc.parent.get_types(p.types)]),
-                    )
-                    if p.types and keyword_doc.parent is not None
-                    else None,
+                    documentation=(
+                        MarkupContent(
+                            kind=MarkupKind.MARKDOWN,
+                            value="\n\n---\n\n".join([t.to_markdown() for t in keyword_doc.parent.get_types(p.types)]),
+                        )
+                        if p.types and keyword_doc.parent is not None
+                        else None
+                    ),
                 )
                 for i, p in enumerate(kw_arguments)
             ],
@@ -173,15 +194,23 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
             active_parameter=argument_index,
         )
 
-    async def signature_help_KeywordCall(  # noqa: N802
-        self, node: ast.AST, document: TextDocument, position: Position, context: Optional[SignatureHelpContext] = None
+    def signature_help_KeywordCall(  # noqa: N802
+        self,
+        node: ast.AST,
+        document: TextDocument,
+        position: Position,
+        context: Optional[SignatureHelpContext] = None,
     ) -> Optional[SignatureHelp]:
         from robot.parsing.lexer.tokens import Token as RobotToken
 
-        return await self._signature_help_KeywordCall_or_Fixture(RobotToken.KEYWORD, node, document, position, context)
+        return self._signature_help_KeywordCall_or_Fixture(RobotToken.KEYWORD, node, document, position, context)
 
-    async def signature_help_Fixture(  # noqa: N802
-        self, node: ast.AST, document: TextDocument, position: Position, context: Optional[SignatureHelpContext] = None
+    def signature_help_Fixture(  # noqa: N802
+        self,
+        node: ast.AST,
+        document: TextDocument,
+        position: Position,
+        context: Optional[SignatureHelpContext] = None,
     ) -> Optional[SignatureHelp]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Fixture
@@ -190,9 +219,9 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         if name_token is None or name_token.value is None or name_token.value.upper() in ("", "NONE"):
             return None
 
-        return await self._signature_help_KeywordCall_or_Fixture(RobotToken.NAME, node, document, position, context)
+        return self._signature_help_KeywordCall_or_Fixture(RobotToken.NAME, node, document, position, context)
 
-    async def signature_help_LibraryImport(  # noqa: N802
+    def signature_help_LibraryImport(  # noqa: N802
         self,
         node: ast.AST,
         document: TextDocument,
@@ -212,21 +241,19 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
         lib_doc: Optional[LibraryDoc] = None
         try:
-            namespace = await self.parent.documents_cache.get_namespace(document)
+            namespace = self.parent.documents_cache.get_namespace(document)
 
-            lib_doc = await namespace.get_imported_library_libdoc(
-                library_node.name, library_node.args, library_node.alias
-            )
+            lib_doc = namespace.get_imported_library_libdoc(library_node.name, library_node.args, library_node.alias)
 
             if lib_doc is None or lib_doc.errors:
-                lib_doc = await namespace.imports_manager.get_libdoc_for_library_import(
+                lib_doc = namespace.imports_manager.get_libdoc_for_library_import(
                     str(library_node.name),
                     (),
                     str(document.uri.to_path().parent),
-                    variables=await namespace.get_resolvable_variables(),
+                    variables=namespace.get_resolvable_variables(),
                 )
 
-        except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
+        except (CancelledError, SystemExit, KeyboardInterrupt):
             raise
         except BaseException:
             return None
@@ -241,7 +268,11 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
         token_at_position = tokens_at_position[-1]
 
-        if token_at_position.type not in [RobotToken.ARGUMENT, RobotToken.EOL, RobotToken.SEPARATOR]:
+        if token_at_position.type not in [
+            RobotToken.ARGUMENT,
+            RobotToken.EOL,
+            RobotToken.SEPARATOR,
+        ]:
             return None
 
         if not lib_doc.inits:
@@ -257,7 +288,7 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
         return None
 
-    async def signature_help_VariablesImport(  # noqa: N802
+    def signature_help_VariablesImport(  # noqa: N802
         self,
         node: ast.AST,
         document: TextDocument,
@@ -278,19 +309,19 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
         lib_doc: Optional[LibraryDoc] = None
         try:
-            namespace = await self.parent.documents_cache.get_namespace(document)
+            namespace = self.parent.documents_cache.get_namespace(document)
 
-            lib_doc = await namespace.get_imported_variables_libdoc(variables_node.name, variables_node.args)
+            lib_doc = namespace.get_variables_import_libdoc(variables_node.name, variables_node.args)
 
             if lib_doc is None or lib_doc.errors:
-                lib_doc = await namespace.imports_manager.get_libdoc_for_variables_import(
+                lib_doc = namespace.imports_manager.get_libdoc_for_variables_import(
                     str(variables_node.name),
                     (),
                     str(document.uri.to_path().parent),
-                    variables=await namespace.get_resolvable_variables(),
+                    variables=namespace.get_resolvable_variables(),
                 )
 
-        except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
+        except (CancelledError, SystemExit, KeyboardInterrupt):
             raise
         except BaseException:
             return None
@@ -301,7 +332,11 @@ class RobotSignatureHelpProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
         token_at_position = tokens_at_position[-1]
 
-        if token_at_position.type not in [RobotToken.ARGUMENT, RobotToken.EOL, RobotToken.SEPARATOR]:
+        if token_at_position.type not in [
+            RobotToken.ARGUMENT,
+            RobotToken.EOL,
+            RobotToken.SEPARATOR,
+        ]:
             return None
 
         if not lib_doc.inits:
